.. raw:: latex

   \frontmatter

====
h5sh
====

.. ***************************************************************************
.. MAIN MATTER
.. ***************************************************************************

.. raw:: latex

   \mainmatter
   \begin{abstract}

This project provides a shell-like interface for navigating and extracting data
from HDF5 files. For large files (multiple GB and higher), it boasts a much
higher performance than the native HDF5-provided command line tools.

.. raw:: latex

   \end{abstract}

.. toctree::
   :maxdepth: 2
   :caption: Contents

   introduction.rst
   commands.rst

.. ***************************************************************************
.. APPENDICES
.. ***************************************************************************

.. raw:: latex

   \appendix

.. toctree::
   :maxdepth: 2
   :caption: Appendices

   appendices/history.rst
   appendices/authors.rst
   appendices/license.rst


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
